@@ -2,6 +2,7 @@
 
     """
 
+import re
 from itertools import product
 from pathlib import Path
 
@@ -153,15 +154,17 @@ def handle_parallel_output(o , df , inds , out_map) :
             df.loc[inds , k] = [x.__getattribute__(v) for x in o]
 
     elif isinstance(out_map , list) :
-        for i , col in enumerate(out_map) :
-            df.loc[inds , col] = [x[i] for x in o]
+
+        if len(out_map) == 1 :
+            df.loc[inds , out_map[0]] = o
+
+        else :
+            for i , col in enumerate(out_map) :
+                df.loc[inds , col] = [x[i] for x in o]
 
     return df
 
 def make_out_map_ready(out_cols_map) :
-    if out_cols_map is None :
-        return
-
     if isinstance(out_cols_map , dict) :
 
         if list(out_cols_map.values())[0] is None :
@@ -185,6 +188,9 @@ def df_apply_parallel(df ,
     if test :
         inds = inds[: min(100 , len(inds))]
 
+    if len(inds) == 0 :
+        return df
+
     inp = make_inputs_4_apply_parallel(df , inds , inp_cols)
 
     o = run_parallel(func , inp , n_jobs , console_run = console_run)
@@ -193,3 +199,21 @@ def df_apply_parallel(df ,
     df = handle_parallel_output(o , df , inds , ocm)
 
     return df
+
+def drop_all_nan_rows_and_cols(df) :
+    df = df.dropna(how = "all")
+    return df.dropna(how = "all" , axis = 1)
+
+def does_df_iloc_val_matches_ptrn(df ,
+                                  iat: tuple ,
+                                  ptrn: (str , None)) -> bool :
+    row , col = iat
+    cell_v = df.iat[row , col]
+
+    if pd.isna(cell_v) and pd.isna(ptrn) :
+        return True
+    elif pd.isna(cell_v) :
+        return False
+
+    cell_v = str(cell_v)
+    return re.fullmatch(ptrn , cell_v) is not None
