@@ -6,9 +6,6 @@ import importlib
 
 import pandas as pd
 
-from src.mirutil import df
-from itertools import product
-
 
 importlib.reload(df_utils)
 
